@@ -1,6 +1,6 @@
 "getstnname" <-
   function(id) {
-    data(mscstn)
+    suppressWarnings(data(mscstn))
     name <- mscstn$name[match(id,mscstn$nid)]
     if(length(name) == 0 || is.na(name)) name <- NULL
     name
