@@ -1,86 +1,35 @@
 "seas.norm" <-
-  function(dat, start, end, var, norm="days", fun="median",
+  function(x, var, fun="median", norm="days", year.filter,
            ann.only=FALSE, precip.norm=FALSE) {
-    orig <- substitute(dat)
-    if(!inherits(dat,"seas.sum"))
-      stop(gettextf("%s is not a %s object",
-                    sQuote(orig), sQuote("seas.sum")))
-    if(missing(var))
-      var <- ifelse(precip.norm,"precip",dat$prime)
-    if(!(var %in% dat$var))
-      stop(gettextf("%s not found in %s",
-                    sQuote(var), sQuote(sprintf("%s$var",orig))))
-    if(!ann.only){
-      if(inherits(norm,"matrix")) {
-        if(!all(dim(norm) == dim(dat$seas[1:2])))
-          stop(gettextf("%s does not have the same dimensions as %s",
-                        sQuote(orig),sQuote("dat$days")))
-        dat$days <- norm
-      }
-      if(inherits(norm,"array")) {
-        if(!all(dim(norm) == dim(dat$seas)))
-          stop(gettextf("%s does not have the same dimensions as %s",
-                        sQuote(orig),sQuote("dat$seas")))
-        dat$norm <- norm
-      } else {
-        if(norm == "active") {
-          if(!"active" %in% names(dat))
-            stop("there is no %s in %s",sQuote("active"),sQuote("orig"))
-          dat$norm <- dat$active
-        } else if(!"norm" %in% names(dat)){
-          dat$norm <- array(dat$days,dim=dim(dat$seas),
-                            dimnames=dimnames(dat$seas))
-        }
-      }
-    }
-    if(precip.norm && (any(!c("rain","snow") %in% dat$var))) {
+    orig <- as.character(substitute(x))[[1]]
+    if(precip.norm && (any(!c("rain","snow") %in% x$var))) {
       warning(paste(gettextf("%s does not have either %s or %s variables, or both",
                              sQuote(orig),sQuote("rain"),sQuote("snow")),
                     gettextf("using only %s",var),sep="\n"))
       precip.norm <- FALSE
     }
-    if(missing(start) || is.null(start)) start <- NULL
-    else {
-      if(missing(end)) end <- start
-      s <- dat$years %in% start:end
-      dat$ann <- dat$ann[s,]
-      if(!ann.only){
-        dat$seas <- dat$seas[s,,,drop=FALSE]
-        dat$norm <- dat$norm[s,,,drop=FALSE]
-        dat$na <- dat$na[s,,drop=FALSE]
-        dat$days <- dat$days[s,,drop=FALSE]
-        if(dat$a.cut)
-          dat$active <- dat$active[s,,,drop=FALSE]
-      }
-      dat$years <- dat$years[s]
-    }
-    n.years <- length(dat$years)
-    if(n.years == 0) {
-      warning("no data")
-      invisible(NA)
-    }
+    x <- seas.sum.check(x,orig,var,norm,year.filter,ann.only)
+    var <- x$var
+    n.years <- length(x$years)
     if(is.function(fun)) fun <- as.character(substitute(fun))[[1]]
-    width <- dat$width
-    dat$range <- range(dat$years)
-    num <- length(dat$bins)
-    # determine annual normals
-    ann <- data.frame(var=NA)
-    var.a <- dat$ann[,var]
-    if(any(!is.na(var.a))) { # are values to calculate annual normals?
+    num <- length(x$bins)
+    ann <- data.frame(var=NA) # determine annual normals
+    var.a <- x$ann[,var]
+    if(any(is.finite(var.a))) { # are values to calculate annual normals?
       ann$var <- eval(call(fun,var.a,na.rm=TRUE))
       if(precip.norm) {
-        rain.a <- dat$ann$rain
-        snow.a <- dat$ann$snow
+        rain.a <- x$ann$rain
+        snow.a <- x$ann$snow
         ann$rain <- eval(call(fun,rain.a,na.rm=TRUE))
         ann$snow <- eval(call(fun,snow.a,na.rm=TRUE))
       }
-      ann$days <- eval(call(fun,dat$ann$days,na.rm=TRUE))
+      ann$days <- eval(call(fun,x$ann$days,na.rm=TRUE))
       ann$active <- NA
-      ann$na <- eval(call(fun,dat$ann$na,na.rm=TRUE))
-    } else { # an incomplete year
+      ann$na <- eval(call(fun,x$ann$na,na.rm=TRUE))
+    } else { # incomplete years
       ann$var <- NA
       if(precip.norm)
-        ann$snow <- ann$rain <- NA
+        ann$snow <- ann$rain <- rain.a <- snow.a <- NA
       ann$active <- ann$days <- NA
       ann$na <- NA
       warning(gettext("not enough data to determine annual normals"))
@@ -90,26 +39,26 @@
         fun <- "mean"
       }
     }
-    if(dat$a.cut) {
-      active.a <- dat$ann$active
-      ann$active <- ifelse(any(!is.na(active.a)),
-                           eval(call(fun,active.a,na.rm=TRUE)),0)
+    if(x$a.cut) {
+      active.a <- x$ann$active
+      ann$active <- if(any(is.finite(active.a)))
+        eval(call(fun,active.a,na.rm=TRUE)) else 0
     } else {
       ann$active <- NULL
     }
     if(!ann.only) {
       # .b suffix is a matrix of sums of bin for each year
-      var.b <- dat$seas[,,var] # drop=TRUE is default
-      norm.b <- dat$norm[,,var]
-      var.n <- dat$seas/dat$norm # normalized
+      var.b <- x$seas[,,var] # drop=TRUE is default
+      norm.b <- x$norm[,,var]
+      var.n <- x$seas/x$norm # normalized
       if(dim(var.n)[1] == 1)
         var.n <- var.n[1,,]
-      var.n[dat$norm <= 0] <- 0
+      var.n[x$norm <= 0] <- 0
       if(precip.norm) {
-        rain.b <- dat$seas[,,"rain"]
-        snow.b <- dat$seas[,,"snow"]
+        rain.b <- x$seas[,,"rain"]
+        snow.b <- x$seas[,,"snow"]
       }
-      seas <- data.frame(var=1:num*NA,row.names=dat$bins)
+      seas <- data.frame(var=1:num*NA,row.names=x$bins)
       if(fun == "median" && n.years <= 2) {
         if(n.years != 1)
           warning("not enough years to find the median; using mean")
@@ -121,10 +70,10 @@
           seas$rain <- var.n[,"rain"]
           seas$snow <- var.n[,"snow"]
         }
-        if(dat$a.cut)
-          seas$active <- dat$active[1,,var]/norm.b
-        seas$days <- dat$days[1,]
-        seas$na <- dat$na[1,]/norm.b
+        if(x$a.cut)
+          seas$active <- x$active[1,,var]/norm.b
+        seas$days <- x$days[1,]
+        seas$na <- x$na[1,]/norm.b
       }else if(fun == "median" && n.years > 2) {
         quan <- data.frame(var=NA)
         secant <- function (f) {
@@ -206,33 +155,33 @@
           # these two operations make the bars equal for
           # precip.norm=TRUE and FALSE
         }
-        if(dat$a.cut && ann$active > 0) {
+        if(x$a.cut && ann$active > 0) {
           quan$active <- secant(function(qu)
-                                return(ann$active - sum(apply(dat$active,2,
+                                return(ann$active - sum(apply(x$active,2,
                                                               quantile,qu,
                                                               na.rm=TRUE,
                                                               names=FALSE))))
-          seas$active <- apply(dat$active[,,var]/norm.b,2,
+          seas$active <- apply(x$active[,,var]/norm.b,2,
                                quantile,quan$active,
                                na.rm=TRUE,names=FALSE)
         }
-        if(all(apply(dat$days,1,function(r)(r==dat$days[1,]))))
+        if(all(apply(x$days,1,function(r)(r==x$days[1,]))))
           quan$days <- .5 # secant method fails if all same value
         else
           quan$days <- secant(function(qu)
-                              return(ann$days - sum(apply(dat$days,2,
+                              return(ann$days - sum(apply(x$days,2,
                                                           quantile,qu,
                                                           na.rm=TRUE,
                                                           names=FALSE))))
-        seas$days <- apply(dat$days,2,quantile,quan$days,
+        seas$days <- apply(x$days,2,quantile,quan$days,
                            na.rm=TRUE,names=FALSE)
         if(ann$na > 0) {
           quan$na <- secant(function(qu)
-                            return(ann$na - sum(apply(dat$na,2,
+                            return(ann$na - sum(apply(x$na,2,
                                                       quantile,qu,
                                                       na.rm=TRUE,
                                                       names=FALSE))))
-          seas$na <- apply(dat$na/norm.b,2,quantile,quan$active,
+          seas$na <- apply(x$na/norm.b,2,quantile,quan$active,
                            na.rm=TRUE,names=FALSE)
         } else seas$na <- quan$days*0
       } else { # calculate stats conventionally (much faster)
@@ -241,10 +190,10 @@
           seas$rain <- apply(var.n[,,"rain"],2,fun,na.rm=TRUE)
           seas$snow <- apply(var.n[,,"snow"],2,fun,na.rm=TRUE)
         }
-        if(dat$a.cut)
-          seas$active <- apply(dat$active[,,var]/norm.b,2,fun,na.rm=TRUE)
-        seas$days <- apply(dat$days,2,fun,na.rm=TRUE)
-        seas$na <- apply(dat$na/norm.b,2,mean,na.rm=TRUE)
+        if(x$a.cut)
+          seas$active <- apply(x$active[,,var]/norm.b,2,fun,na.rm=TRUE)
+        seas$days <- apply(x$days,2,fun,na.rm=TRUE)
+        seas$na <- apply(x$na/norm.b,2,mean,na.rm=TRUE)
       }
     } # end if (!ann.only)
     fixnames <- function(n){
@@ -257,32 +206,32 @@
       attr(l,"class") <- "seas.norm"
       names(seas) <- fixnames(names(seas))
       l$seas <- seas
-      l$width <- dat$width
-      l$bins <- dat$bins
+      l$width <- x$width
+      l$bins <- x$bins
+      l$bin.lengths <- x$bin.lengths
     }
+    l$start.day <- x$start.day
+    l$year.range <- x$year.range
     l$var <- var
-    l$prime <- dat$prime
-    l$unit <- dat$unit
+    l$long.name <- x$long.name[[var]]
+    l$units <- x$units[[var]]
     l$norm <- norm
     l$ann.only <- ann.only
     l$precip.norm <- precip.norm
-    l$a.cut <- dat$a.cut
+    l$a.cut <- x$a.cut
     if(n.years > 1)
       l$fun <- fun
     if(!ann.only && fun == "median") {
       names(quan) <- fixnames(names(quan))
       l$quantile <- quan
     }
-    l$range <- dat$range
-    l$id <- dat$id
-    l$name <- dat$name
+    l$id <- x$id
+    l$name <- x$name
     l
   }
 
 "precip.norm" <-
-  function(dat, start, end, fun="median",...) {
-    if(missing(start)) start <- NULL
-    if(missing(end)) end <- start
-    if(is.function(fun)) fun <- as.character(substitute(fun))
-    seas.norm(dat=dat,start=start,end=end,fun=fun,precip.norm=TRUE,...)
+  function(x, fun="median", norm="days", year.filter) {
+    if(is.function(fun)) fun <- as.character(substitute(fun))[[1]]
+    seas.norm(x,norm=norm,year.filter=year.filter,fun=fun,precip.norm=TRUE)
   }
